@@ -1,5 +1,5 @@
 package encoding;
-our $VERSION = do { my @r = (q$Revision: 1.27 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.30 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use Encode;
 use strict;
@@ -11,15 +11,8 @@ BEGIN {
     }
 }
 
-our $HAS_PERLIO_ENCODING;
-
-eval { binmode(STDIN, ":encoding(ascii)"); };
-if ($@){
-    $HAS_PERLIO_ENCODING = 0;
-}else{
-    $HAS_PERLIO_ENCODING = 1;
-    binmode(STDIN);
-}
+our $HAS_PERLIO = exists $INC{"PerlIO/encoding.pm"};
+$HAS_PERLIO or binmode(STDIN);
 
 sub import {
     my $class = shift;
@@ -34,7 +27,7 @@ sub import {
     }
     unless ($arg{Filter}){
 	${^ENCODING} = $enc; # this is all you need, actually.
-	$HAS_PERLIO_ENCODING or return 1;
+	$HAS_PERLIO or return 1;
 	for my $h (qw(STDIN STDOUT)){
 	    if ($arg{$h}){
 		unless (defined find_encoding($arg{$h})) {
@@ -85,6 +78,7 @@ sub unimport{
 
 1;
 __END__
+
 =pod
 
 =head1 NAME
@@ -93,20 +87,23 @@ encoding -  allows you to write your script in non-asii or non-utf8
 
 =head1 SYNOPSIS
 
+  use encoding "greek";  # Perl like Greek to you?
   use encoding "euc-jp"; # Jperl!
 
-  # or you can even do this if your shell supports euc-jp
+  # or you can even do this if your shell supports your native encoding
 
-  > perl -Mencoding=euc-jp -e '...'
+  perl -Mencoding=latin2 -e '...' # Feeling centrally European?
+  perl -Mencoding=euc-ko -e '...'
 
   # or from the shebang line
 
-  #!/your/path/to/perl -Mencoding=euc-jp
+  #!/your/path/to/perl -Mencoding="8859-6" # Arabian Nights
+  #!/your/path/to/perl -Mencoding=euc-tw
 
   # more control
 
-  # A simple euc-jp => utf-8 converter
-  use encoding "euc-jp", STDOUT => "utf8";  while(<>){print};
+  # A simple euc-cn => utf-8 converter
+  use encoding "euc-cn", STDOUT => "utf8";  while(<>){print};
 
   # "no encoding;" supported (but not scoped!)
   no encoding;
@@ -118,27 +115,29 @@ encoding -  allows you to write your script in non-asii or non-utf8
 
 =head1 ABSTRACT
 
-Perl 5.6.0 has introduced Unicode support.  You could apply
-C<substr()> and regexes even to complex CJK characters -- so long as
-the script was written in UTF-8.  But back then text editors that
-support UTF-8 was still rare and many users rather chose to writer
-scripts in legacy encodings, given up whole new feature of Perl 5.6.
+Let's start with a bit of history: Perl 5.6.0 introduced Unicode
+support.  You could apply C<substr()> and regexes even to complex CJK
+characters -- so long as the script was written in UTF-8.  But back
+then text editors that supported UTF-8 were still rare and many users
+rather chose to write scripts in legacy encodings, given up whole new
+feature of Perl 5.6.
 
-With B<encoding> pragma, you can write your script in any encoding you like
-(so long as the C<Encode> module supports it) and still enjoy Unicode
-support.  You can write a code in EUC-JP as follows;
+Rewind to the future: starting from perl 5.8.0 with B<encoding>
+pragma, you can write your script in any encoding you like (so long
+as the C<Encode> module supports it) and still enjoy Unicode support.
+You can write a code in EUC-JP as follows:
 
   my $Rakuda = "\xF1\xD1\xF1\xCC"; # Camel in Kanji
                #<-char-><-char->   # 4 octets
   s/\bCamel\b/$Rakuda/;
 
 And with C<use encoding "euc-jp"> in effect, it is the same thing as
-the code in UTF-8 as follow.
+the code in UTF-8:
 
   my $Rakuda = "\x{99F1}\x{99DD}"; # who Unicode Characters
   s/\bCamel\b/$Rakuda/;
 
-The B<encoding> pragma also modifies the file handle disciplines of
+The B<encoding> pragma also modifies the filehandle disciplines of
 STDIN, STDOUT, and STDERR to the specified encoding.  Therefore,
 
   use encoding "euc-jp";
@@ -147,10 +146,10 @@ STDIN, STDOUT, and STDERR to the specified encoding.  Therefore,
   $message =~ s/\bCamel\b/$Rakuda/;
   print $message;
 
-Will print "\xF1\xD1\xF1\xCC is the symbol of perl.\n", not
-"\x{99F1}\x{99DD} is the symbol of perl.\n".
+Will print "\xF1\xD1\xF1\xCC is the symbol of perl.\n",
+not "\x{99F1}\x{99DD} is the symbol of perl.\n".
 
-You can override this by giving extra arguments.  See below.
+You can override this by giving extra arguments, see below.
 
 =head1 USAGE
 
@@ -158,13 +157,13 @@ You can override this by giving extra arguments.  See below.
 
 =item use encoding [I<ENCNAME>] ;
 
-Sets the script encoding to I<ENCNAME> and file handle disciplines of
-STDIN, STDOUT are set to ":encoding(I<ENCNAME>)". Note STDERR will not 
-be changed.
+Sets the script encoding to I<ENCNAME> and filehandle disciplines of
+STDIN, STDOUT are set to ":encoding(I<ENCNAME>)".  Note STDERR will
+not be changed.
 
 If no encoding is specified, the environment variable L<PERL_ENCODING>
-is consulted. If no  encoding can be found, C<Unknown encoding 'I<ENCNAME>'>
-error will be thrown. 
+is consulted.  If no encoding can be found, the error C<Unknown encoding
+'I<ENCNAME>'> will be thrown.
 
 Note that non-STD file handles remain unaffected.  Use C<use open> or
 C<binmode> to change disciplines of those.
@@ -173,13 +172,13 @@ C<binmode> to change disciplines of those.
 
 You can also individually set encodings of STDIN and STDOUT via
 STDI<FH> =E<gt> I<ENCNAME_FH> form.  In this case, you cannot omit the
-first I<ENCNAME>.  C<STDI<FH> =E<gt> undef> turns IO transcoding
+first I<ENCNAME>.  C<STDI<FH> =E<gt> undef> turns the IO transcoding
 completely off.
 
 =item no encoding;
 
 Unsets the script encoding and the disciplines of STDIN, STDOUT are
-reset to ":raw".
+reset to ":raw" (the default unprocessed raw stream of bytes).
 
 =back
 
@@ -189,8 +188,8 @@ reset to ":raw".
 
 The pragma is a per script, not a per block lexical.  Only the last
 C<use encoding> or C<matters, and it affects B<the whole script>.
-Though <no encoding> pragma is supported and C<use encoding> can
-appear as many times as you want in a given script, the multiple use
+However, <no encoding> pragma is supported and C<use encoding> can
+appear as many times as you want in a given script.  The multiple use
 of this pragma is discouraged.
 
 =head2 DO NOT MIX MULTIPLE ENCODINGS
@@ -209,9 +208,10 @@ but this will not
 
 	"\xDF\x{100}" =~ /\x{3af}\x{100}/
 
-since the C<\xDF> on the left will B<not> be upgraded to C<\x{3af}>
-because of the C<\x{100}> on the left.  You should not be mixing your
-legacy data and Unicode in the same string.
+since the C<\xDF> (ISO 8859-7 GREEK SMALL LETTER IOTA WITH TONOS) on
+the left will B<not> be upgraded to C<\x{3af}> (Unicode GREEK SMALL
+LETTER IOTA WITH TONOS) because of the C<\x{100}> on the left.  You
+should not be mixing your legacy data and Unicode in the same string.
 
 This pragma also affects encoding of the 0x80..0xFF code point range:
 normally characters in that range are left as eight-bit bytes (unless
@@ -221,18 +221,19 @@ the C<encoding> pragma is present, even the 0x80..0xFF range always
 gets UTF-8 encoded.
 
 After all, the best thing about this pragma is that you don't have to
-resort to \x... just to spell your name in native encoding.  So feel
+resort to \x... just to spell your name in native a encoding.  So feel
 free to put your strings in your encoding in quotes and regexes.
 
-=head1 NON-ASCII Identifiers and Filter option
+=head1 Non-ASCII Identifiers and Filter option
 
-The magic of C<use encoding> is not applied to the names of identifiers.
-In order to make C<${"4eba"}++> ($man++, where man is a single ideograph)
-work, you still need to write your script in UTF-8 or use a source filter.
+The magic of C<use encoding> is not applied to the names of
+identifiers.  In order to make C<${"4eba"}++> ($human++, where human
+is a single Han ideograph) work, you still need to write your script
+in UTF-8 or use a source filter.
 
 In other words, the same restriction as Jperl applies.
 
-If you dare experiment, however, you can try Fitlter option.
+If you dare to experiment, however, you can try Filter option.
 
 =over 4
 
@@ -245,19 +246,17 @@ and STDOUT remain untouched.
 
 =back
 
-What does this mean?  Your source code behaves as if it is written 
-in UTF-8.  So even if your editor only supports Shift_JIS, for 
-example.  You can still try examples in Chapter 15 of 
-C<Programming Perl, 3rd Ed.>  For instance, you can use UTF-8
-identifiers.
+What does this mean?  Your source code behaves as if it is written in
+UTF-8.  So even if your editor only supports Shift_JIS, for example.
+You can still try examples in Chapter 15 of C<Programming Perl, 3rd
+Ed.> For instance, you can use UTF-8 identifiers.
 
 This option is significantly slower and (as of this writing) non-ASCII
 identifiers are not very stable WITHOUT this option and with the
 source code written in UTF-8.
 
-To make your script in legacy encoding work with minimum effort, do
-not use Filter=E<gt>1
-
+To make your script in legacy encoding work with minimum effort,
+do not use Filter=E<gt>1.
 
 =head1 EXAMPLE - Greekperl
 
